@@ -28,6 +28,7 @@
 
 #include <fstream>
 #include <memory>
+#include <cstring>  // memset
 
 
 // #include <boost/unordered_map.hpp>
@@ -114,6 +115,9 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
     std::unique_ptr<char[]> metaP(new char[metaSize]);
     char* meta = metaP.get();
 
+    // clear memory for safety
+    memset(meta, 0, metaSize);
+
     // Set column header
     unsigned int* isCompressed = reinterpret_cast<unsigned int*>(meta);
     unsigned int* blockSizeChar = reinterpret_cast<unsigned int*>(&meta[4]);
@@ -151,6 +155,9 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
   std::unique_ptr<char[]> metaP(new char[metaSize]);
   char* meta = metaP.get();
 
+  // clear memory for safety
+  memset(meta, 0, metaSize);
+
   // Set column header
   unsigned int* isCompressed = reinterpret_cast<unsigned int*>(meta);
   unsigned int* blockSizeChar = reinterpret_cast<unsigned int*>(&meta[4]);
@@ -204,7 +211,7 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
 
     stringWriter->SetBuffersFromVec(block * BLOCKSIZE_CHAR, (block + 1) * BLOCKSIZE_CHAR);
     unsigned long long totSize = storeCharBlockCompressed_v6(myfile, stringWriter, block * BLOCKSIZE_CHAR,
-                                                             (block + 1) * BLOCKSIZE_CHAR, streamCompressInt, streamCompressChar, *algoInt, *algoChar, *intBufSize, block);
+      (block + 1) * BLOCKSIZE_CHAR, streamCompressInt, streamCompressChar, *algoInt, *algoChar, *intBufSize, block);
 
     fullSize += totSize;
     *blockPos = fullSize;
@@ -218,7 +225,7 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
 
   stringWriter->SetBuffersFromVec(nrOfBlocks * BLOCKSIZE_CHAR, vecLength);
   unsigned long long totSize = storeCharBlockCompressed_v6(myfile, stringWriter, nrOfBlocks * BLOCKSIZE_CHAR,
-                                                           vecLength, streamCompressInt, streamCompressChar, *algoInt, *algoChar, *intBufSize, nrOfBlocks);
+    vecLength, streamCompressInt, streamCompressChar, *algoInt, *algoChar, *intBufSize, nrOfBlocks);
 
   fullSize += totSize;
   *blockPos = fullSize;
